Class: RubyAiGemContext::Platforms::Claude
Class Method Summary
collapse
backup, exists?, full_path, path, read, write
Class Method Details
.description ⇒ Object
15
16
17
|
# File 'lib/ruby_ai_gem_context/platforms/claude.rb', line 15
def description
"Claude Code / Claude AI - Project context file"
end
|
.filename ⇒ Object
11
12
13
|
# File 'lib/ruby_ai_gem_context/platforms/claude.rb', line 11
def filename
"CLAUDE.md"
end
|
.generation_prompt ⇒ Object
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
|
# File 'lib/ruby_ai_gem_context/platforms/claude.rb', line 19
def generation_prompt
" Generate a CLAUDE.md file for this Ruby project. This file helps Claude Code understand the project.\n\n Structure the file with these sections:\n\n # Project Name\n\n Brief description of what this project does.\n\n ## Quick Start\n\n How to set up and run the project (install deps, run tests, start server, etc.)\n\n ## Architecture\n\n Key architectural decisions, folder structure, important patterns used.\n\n ## Code Style\n\n Coding conventions, naming patterns, formatting preferences for this project.\n\n ## Common Tasks\n\n Frequent development tasks and how to do them (run tests, lint, deploy, etc.)\n\n ## Key Files\n\n Important files to understand the codebase (entry points, config, core classes).\n\n ## Gotchas\n\n Non-obvious things, common mistakes, edge cases to watch out for.\n\n Keep it concise and practical. Focus on information that helps an AI assistant understand and work with this codebase effectively.\n PROMPT\nend\n"
|
.name ⇒ Object
7
8
9
|
# File 'lib/ruby_ai_gem_context/platforms/claude.rb', line 7
def name
"Claude Code"
end
|
.template ⇒ Object
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
|
# File 'lib/ruby_ai_gem_context/platforms/claude.rb', line 57
def template
" # Project Name\n\n Brief description of what this project does.\n\n ## Quick Start\n\n ```bash\n # Install dependencies\n bundle install\n\n # Run tests\n bundle exec rspec\n\n # Start development\n # Add commands here\n ```\n\n ## Architecture\n\n Describe the key architectural decisions and patterns used in this project.\n\n ## Code Style\n\n - Ruby style conventions used\n - Naming patterns\n - File organization\n\n ## Common Tasks\n\n - **Run tests**: `bundle exec rspec`\n - **Run linter**: `bundle exec rubocop`\n - **Generate docs**: `bundle exec yard`\n\n ## Key Files\n\n - `lib/` - Main library code\n - `spec/` - Test files\n - `Gemfile` - Dependencies\n\n ## Gotchas\n\n - Things to watch out for\n - Common mistakes\n - Non-obvious behaviors\n TEMPLATE\nend\n"
|